@@ -11,7 +11,7 @@ template<typename... Ts> class TriggerEventAction : public Action<Ts...>, public
  public:
   TEMPLATABLE_VALUE(std::string, event_type)
 
-  void play(Ts... x) override { this->parent_->trigger(this->event_type_.value(x...)); }
+  void play(const Ts &...x) override { this->parent_->trigger(this->event_type_.value(x...)); }
 };
 
 class EventTrigger : public Trigger<std::string> {
