@@ -148,9 +148,11 @@ void Logger::log_vprintf_(uint8_t level, const char *tag, int line, const __Flas
 #endif  // USE_STORE_LOG_STR_IN_FLASH
 
 inline uint8_t Logger::level_for(const char *tag) {
+#ifdef USE_LOGGER_RUNTIME_TAG_LEVELS
   auto it = this->log_levels_.find(tag);
   if (it != this->log_levels_.end())
     return it->second;
+#endif
   return this->current_level_;
 }
 
@@ -173,24 +175,8 @@ void Logger::init_log_buffer(size_t total_buffer_size) {
 }
 #endif
 
-#ifndef USE_ZEPHYR
-#if defined(USE_LOGGER_USB_CDC) || defined(USE_ESP32)
-void Logger::loop() {
-#if defined(USE_LOGGER_USB_CDC) && defined(USE_ARDUINO)
-  if (this->uart_ == UART_SELECTION_USB_CDC) {
-    static bool opened = false;
-    if (opened == Serial) {
-      return;
-    }
-    if (false == opened) {
-      App.schedule_dump_config();
-    }
-    opened = !opened;
-  }
-#endif
-  this->process_messages_();
-}
-#endif
+#ifdef USE_ESPHOME_TASK_LOG_BUFFER
+void Logger::loop() { this->process_messages_(); }
 #endif
 
 void Logger::process_messages_() {
@@ -236,7 +222,9 @@ void Logger::process_messages_() {
 }
 
 void Logger::set_baud_rate(uint32_t baud_rate) { this->baud_rate_ = baud_rate; }
-void Logger::set_log_level(const std::string &tag, uint8_t log_level) { this->log_levels_[tag] = log_level; }
+#ifdef USE_LOGGER_RUNTIME_TAG_LEVELS
+void Logger::set_log_level(const char *tag, uint8_t log_level) { this->log_levels_[tag] = log_level; }
+#endif
 
 #if defined(USE_ESP32) || defined(USE_ESP8266) || defined(USE_RP2040) || defined(USE_LIBRETINY) || defined(USE_ZEPHYR)
 UARTSelection Logger::get_uart() const { return this->uart_; }
@@ -287,9 +275,11 @@ void Logger::dump_config() {
   }
 #endif
 
+#ifdef USE_LOGGER_RUNTIME_TAG_LEVELS
   for (auto &it : this->log_levels_) {
-    ESP_LOGCONFIG(TAG, "  Level for '%s': %s", it.first.c_str(), LOG_STR_ARG(LOG_LEVELS[it.second]));
+    ESP_LOGCONFIG(TAG, "  Level for '%s': %s", it.first, LOG_STR_ARG(LOG_LEVELS[it.second]));
   }
+#endif
 }
 
 void Logger::set_log_level(uint8_t level) {
