@@ -1,10 +1,7 @@
 import esphome.codegen as cg
-import esphome.config_validation as cv
 from esphome.components import switch
-from esphome.const import (
-    ENTITY_CATEGORY_CONFIG,
-    ICON_POWER,
-)
+import esphome.config_validation as cv
+from esphome.const import ENTITY_CATEGORY_CONFIG, ICON_POWER
 
 shutdown_ns = cg.esphome_ns.namespace("shutdown")
 ShutdownSwitch = shutdown_ns.class_("ShutdownSwitch", switch.Switch, cg.Component)
