@@ -6,6 +6,8 @@ from esphome.const import (
     CONF_BRIGHTNESS,
     CONF_CONTRAST,
     CONF_EXTERNAL_VCC,
+    CONF_FLIP_X,
+    CONF_FLIP_Y,
     CONF_INVERT,
     CONF_LAMBDA,
     CONF_MODEL,
@@ -18,9 +20,6 @@ ssd1306_base_ns = cg.esphome_ns.namespace("ssd1306_base")
 SSD1306 = ssd1306_base_ns.class_("SSD1306", cg.PollingComponent, display.DisplayBuffer)
 SSD1306Model = ssd1306_base_ns.enum("SSD1306Model")
 
-CONF_FLIP_X = "flip_x"
-CONF_FLIP_Y = "flip_y"
-
 MODELS = {
     "SSD1306_128X32": SSD1306Model.SSD1306_MODEL_128_32,
     "SSD1306_128X64": SSD1306Model.SSD1306_MODEL_128_64,
@@ -43,14 +42,15 @@ SSD1306_MODEL = cv.enum(MODELS, upper=True, space="_")
 
 def _validate(value):
     model = value[CONF_MODEL]
-    if model not in ("SSD1305_128X32", "SSD1305_128X64"):
-        # Contrast is default value (1.0) while brightness is not
-        # Indicates user is using old `brightness` option
-        if value[CONF_BRIGHTNESS] != 1.0 and value[CONF_CONTRAST] == 1.0:
-            raise cv.Invalid(
-                "SSD1306/SH1106 no longer accepts brightness option, "
-                'please use "contrast" instead.'
-            )
+    if (
+        model not in ("SSD1305_128X32", "SSD1305_128X64")
+        and value[CONF_BRIGHTNESS] != 1.0
+        and value[CONF_CONTRAST] == 1.0
+    ):
+        raise cv.Invalid(
+            "SSD1306/SH1106 no longer accepts brightness option, "
+            'please use "contrast" instead.'
+        )
 
     return value
 
