@@ -5,7 +5,7 @@
 namespace esphome {
 namespace template_ {
 
-class TemplateButton : public button::Button {
+class TemplateButton final : public button::Button {
  public:
   // Implements the abstract `press_action` but the `on_press` trigger already handles the press.
   void press_action() override{};
